'use strict';

var react = require('react');
var reactRouterDom = require('react-router-dom');
var uuid = require('uuid');
var applicationShellConnectors = require('@commercetools-frontend/application-shell-connectors');
var constants = require('@commercetools-frontend/constants');
var urlUtils = require('@commercetools-frontend/url-utils');
var oidc = require('./oidc-d74e6aa2.cjs.prod.js');
var useIsServedByProxy = require('./use-is-served-by-proxy-480e8de8.cjs.prod.js');
var getMcOrigin = require('./get-mc-origin-8f7a578c.cjs.prod.js');
var redirector = require('./redirector-01f35da8.cjs.prod.js');
require('@babel/runtime-corejs3/core-js-stable/instance/map');
require('@babel/runtime-corejs3/core-js-stable/instance/for-each');
require('@babel/runtime-corejs3/helpers/slicedToArray');
require('@babel/runtime-corejs3/core-js-stable/url');
require('@babel/runtime-corejs3/core-js-stable/instance/reverse');
require('@babel/runtime-corejs3/core-js-stable/object/keys');
require('@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols');
require('@babel/runtime-corejs3/core-js-stable/instance/filter');
require('@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor');
require('@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptors');
require('@babel/runtime-corejs3/core-js-stable/object/define-properties');
require('@babel/runtime-corejs3/core-js-stable/object/define-property');
require('@babel/runtime-corejs3/helpers/defineProperty');
require('prop-types');
require('qss');
require('./location-537e0660.cjs.prod.js');

const generateAndCacheNonceWithState = state => {
  const nonce = uuid.v4();
  // We store additional information within the given `nonce`
  // to then retrieve it later when the IdP redirects back
  // to our application. The URL will contain the `nonce` within
  // the id_token and, once validated, we can retrieve and use
  // the state object.
  // https://auth0.com/docs/protocols/oauth2/oauth-state#how-to-use-the-parameter-to-restore-application-state
  applicationShellConnectors.oidcStorage.setSessionState(nonce, state);
  return nonce;
};
const RedirectToLogin = () => {
  const location = reactRouterDom.useLocation();
  const servedByProxy = useIsServedByProxy.useIsServedByProxy();
  const redirector$1 = redirector.useRedirector();
  react.useEffect(() => {
    if (window.app.__DEVELOPMENT__?.oidc?.authorizeUrl) {
      // Remove the `sessionToken` from storage, so that the AppShell can initiate
      // a new authorization flow.
      applicationShellConnectors.oidcStorage.clearSession();

      // We pick the project key from local storage. This assumes that the value
      // as been previously set when the application starts up.
      // This is necessary to allow switching projects and triggering a new login.
      const nextProjectKey = applicationShellConnectors.oidcStorage.getActiveProjectKey();

      // According to the OIDC spec, the `state` parameter is recommended to be sent
      // to the authorization server to help mitigating Cross-Site Request Forgery.
      // https://openid.net/specs/openid-connect-core-1_0.html#AuthRequest
      // Using `state` or `nonce` is very similar but with subtle differences.
      // Here we follow the approach described by Auth0 on how to use both, where
      // we generate a `nonce`, store it in session storage together with some state,
      // and send it to the authorization server as the `state` parameter.
      // https://auth0.com/docs/protocols/oauth2/redirect-users
      // Additionally, we still send the `nonce` parameter as well.
      const sessionId = generateAndCacheNonceWithState({
        applicationId: window.app.applicationId,
        // Store query parameters to be used after the callback redirect
        query: {
          redirectTo: nextProjectKey ? `/${nextProjectKey}` : '/'
        }
      });
      const requestedScope = oidc.buildOidcScope({
        projectKey: nextProjectKey ?? undefined,
        oAuthScopes: window.app.__DEVELOPMENT__?.oidc?.oAuthScopes,
        additionalOAuthScopes: window.app.__DEVELOPMENT__?.oidc?.additionalOAuthScopes,
        teamId: window.app.__DEVELOPMENT__?.oidc?.teamId,
        applicationId: window.app.__DEVELOPMENT__?.oidc?.applicationId
      });

      // Store session scopes, to be able to detect if requested scopes changed
      // in the application config and invalidate the session.
      // This is only valid for local development.
      applicationShellConnectors.oidcStorage.setSessionScope(requestedScope);
      redirector$1({
        to: '',
        origin: window.app.__DEVELOPMENT__?.oidc?.authorizeUrl,
        location: location,
        queryParams: {
          reason: constants.LOGOUT_REASONS.UNAUTHORIZED,
          // Query parameters for OIDC-lik workflow.
          client_id: window.app.applicationId,
          response_type: oidc.OIDC_RESPONSE_TYPES.ID_TOKEN,
          scope: requestedScope,
          state: sessionId,
          nonce: sessionId
        }
      });
      return;
    }
    const mcOrigin = servedByProxy ? getMcOrigin.getMcOrigin(window.app.mcApiUrl) : undefined;
    redirector$1({
      to: 'login',
      origin: mcOrigin,
      location: location,
      queryParams: {
        reason: constants.LOGOUT_REASONS.UNAUTHORIZED,
        redirectTo: urlUtils.trimLeadingAndTrailingSlashes(urlUtils.joinPaths(window.location.origin, location.pathname))
      }
    });

    // Only execute once!
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);
  return null;
};
RedirectToLogin.displayName = 'RedirectToLogin';

exports["default"] = RedirectToLogin;
